@@ -82,7 +82,7 @@ class BluexpressHandler:
                 'largo': 10,
                 'ancho': 10,
                 'alto': 10,
-            }
+            } for _ in range(instance.lumps)
         ]
 
         payload = {
@@ -125,7 +125,6 @@ class BluexpressHandler:
             'centroCosto': xsd.SkipValue,
             'switchNotificar': 'false',
             'codigoAgencia': '0',
-            'cantidadPiezas': instance.lumps,
             'listaEmisionEmbalajesCrearReq': {
                 'emisionEmbalajeCrearReq': lista_items
             },
